Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6270)

Unified Diff: chrome/browser/chromeos/login/enrollment/enrollment_screen_view.h

Issue 2700303002: cros: Unify oobe View/Actor naming to just View. (Closed)
Patch Set: Rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/enrollment/enrollment_screen_view.h
diff --git a/chrome/browser/chromeos/login/enrollment/enrollment_screen_actor.h b/chrome/browser/chromeos/login/enrollment/enrollment_screen_view.h
similarity index 92%
rename from chrome/browser/chromeos/login/enrollment/enrollment_screen_actor.h
rename to chrome/browser/chromeos/login/enrollment/enrollment_screen_view.h
index bcb27b10a0c58a17af971b06bf1ead7b0e931d57..9b438498467c53d2f27522673ea4874595af0cef 100644
--- a/chrome/browser/chromeos/login/enrollment/enrollment_screen_actor.h
+++ b/chrome/browser/chromeos/login/enrollment/enrollment_screen_view.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_CHROMEOS_LOGIN_ENROLLMENT_ENROLLMENT_SCREEN_ACTOR_H_
-#define CHROME_BROWSER_CHROMEOS_LOGIN_ENROLLMENT_ENROLLMENT_SCREEN_ACTOR_H_
+#ifndef CHROME_BROWSER_CHROMEOS_LOGIN_ENROLLMENT_ENROLLMENT_SCREEN_VIEW_H_
+#define CHROME_BROWSER_CHROMEOS_LOGIN_ENROLLMENT_ENROLLMENT_SCREEN_VIEW_H_
#include <string>
@@ -18,8 +18,8 @@ class EnrollmentStatus;
namespace chromeos {
-// Interface class for the enterprise enrollment screen actor.
-class EnrollmentScreenActor {
+// Interface class for the enterprise enrollment screen view.
+class EnrollmentScreenView {
public:
// This defines the interface for controllers which will be called back when
// something happens on the UI.
@@ -37,9 +37,9 @@ class EnrollmentScreenActor {
const std::string& location) = 0;
};
- virtual ~EnrollmentScreenActor() {}
+ virtual ~EnrollmentScreenView() {}
- // Initializes the actor with parameters.
+ // Initializes the view with parameters.
virtual void SetParameters(Controller* controller,
const policy::EnrollmentConfig& config) = 0;
@@ -78,4 +78,4 @@ class EnrollmentScreenActor {
} // namespace chromeos
-#endif // CHROME_BROWSER_CHROMEOS_LOGIN_ENROLLMENT_ENROLLMENT_SCREEN_ACTOR_H_
+#endif // CHROME_BROWSER_CHROMEOS_LOGIN_ENROLLMENT_ENROLLMENT_SCREEN_VIEW_H_

Powered by Google App Engine
This is Rietveld 408576698